@@ -174,6 +174,16 @@ class A3Behavior extends Behavior {
         if (billboardControl&&autoDirectionControl)
             autoDirectionControl=false;
     }
+    void setTransformImmediately(Transform3D t) {
+        nowS = t.getScale();
+        t.get(nowV);
+        t.get(nowQ);
+        nextS = nowS;
+        nextV.set(nowV);
+        nextQ.set(nowQ);
+        //setNow();
+        needRecalc = true;
+    }
     void move(Vector3d v, Quat4d q, double s) {
         if (isInterpolate) {
             nextS = s;
