@@ -15,7 +15,7 @@ public abstract class A3Object {
 //    protected static final Serializable NULL = A23.NULL;
 
     A3Behavior behavior = null;
-    Component2DContainerInterface component2DContainer = null;
+    Component2DContainerInterface component2DContainer = null;//このA3Objectがシーングラフに追加されているかどうかの判定にも使うことにする。
     A3Label label = null;
     A3Balloon balloon = null;
     A3Selected selected = null;
@@ -632,6 +632,7 @@ public abstract class A3Object {
                 component2DContainer.del(balloon);
             if (selected!=null)
                 component2DContainer.del(selected);
+            component2DContainer = null;
         }
     }
 
