@@ -131,6 +131,11 @@ public class A3SubCanvas extends Canvas3D implements A3CanvasInterface, Componen
         subCamBehavior.setA3VirtualUniverse(vu);
     }
 
+    @Override
+    public A3VirtualUniverse getVirtualUniverse() {
+        return virtualUniverse;
+    }
+
     //カメラ制御
     @Override
     public void setDefaultCameraLoc(double x,double y,double z) {
@@ -568,6 +573,11 @@ public class A3SubCanvas extends Canvas3D implements A3CanvasInterface, Componen
         return pickingBehavior.pickA3(x,y);
     }
 
+    @Override
+    public A3Object pick(Vector3d origin,Vector3d dir) {
+        return pickingBehavior.pickA3(origin,dir);
+    }
+
     @Override
     public Dimension getCanvasSize() {
         return this.getSize();
