@@ -91,6 +91,11 @@ class ActionBehavior extends Behavior implements Cloneable {
             a3.label.setOffset(x,y);
         }
     }
+    void resetSoundLocAndQuat() {
+        Vector3d loc = a3.getTargetLoc();
+        Quat4d quat = a3.getTargetQuat();
+        a3Data.actions[actionNo].setSoundLocQuat(loc,quat);
+    }
     void resetParameters() {
         playCount = 0;
         playStatus = S0;
@@ -112,6 +117,7 @@ class ActionBehavior extends Behavior implements Cloneable {
         }
         resetBalloonParameters();
         resetLabelParameters();
+        resetSoundLocAndQuat();
     }
     void doChangeAction(int newActionNo) {
         a3Data.actions[actionNo].stop();
@@ -134,10 +140,10 @@ class ActionBehavior extends Behavior implements Cloneable {
     public void initialize() {
         if (elapsedTime==0) //<-- なんでこれが必要なのか
             return;         //<-- わからない
-        //WakeupOnElapsedTime w = new WakeupOnElapsedTime(elapsedTime);
-        //wakeupOn(w);
         timeOffset = System.currentTimeMillis();
-        processStimulus(null);
+        WakeupOnElapsedTime w = new WakeupOnElapsedTime(1);
+        wakeupOn(w);
+        //processStimulus(null);//これをやっちゃうと着せ替え機能で問題あり
     }
     @SuppressWarnings("unchecked")
     public void processStimulus(Enumeration criteria) {
@@ -296,6 +302,8 @@ class ActionBehavior extends Behavior implements Cloneable {
             //gaha?
             if ((newActionNo<0)||(newActionNo>=a3Data.actions.length))
                 return;
+            if (a3.component2DContainer==null)
+                doChangeAction(newActionNo);
             if (actionQueue.size()<ACTION_QUEUE_SIZE)
                 actionQueue.add(newActionNo);
             else
@@ -313,6 +321,8 @@ class ActionBehavior extends Behavior implements Cloneable {
             //gaha?
             if ((newActionNo<0)||(newActionNo>=a3Data.actions.length))
                 return;
+            if (a3.component2DContainer==null)
+                doChangeAction(newActionNo);
             actionQueue.clear();
             actionQueue.add(newActionNo);
             immediatelyFlag = true;
@@ -499,6 +509,49 @@ class ActionBehavior extends Behavior implements Cloneable {
     void setShape(Serializable action,String boneName,Node shape) {
         a3Data.setShape(action,boneName,shape);
     }
+    /**
+     * このAction3Dで使用されている全てのShapeのファイル名を
+     * 返す．同じShapeが異なるBoneやActionで共有されている場合でも，
+     * 返り値は重複しないようになっている．
+     */
+    String[] getShapeFilenames() {
+        return a3Data.getShapeFilenames();
+    }
+
+    /**
+     * このAction3Dで使用されていShapeをファイル名で指定し，
+     * そのShapeを引数で指定されたJava3DのNodeに変更します．
+     * 変更前のShapeが異なるBoneやActionで共有されている場合には
+     * その全てをnodeに置き換えます．この置き換えにはSharedGroupと
+     * Linkを使った実装が使われます．
+     */
+    void replaceShape(String shapeFilename,Node node) {
+        a3Data.replaceShape(shapeFilename,node);
+    }
+
+    /**
+     * このAction3Dで使用されていShapeをファイル名で指定し，
+     * そのShapeを引数で指定されたURLから生成されるAction3Dの
+     * getNode()メソッドで得られるNodeで置き換えます．
+     * 変更前のShapeが異なるBoneやActionで共有されている場合には
+     * その全てを置き換えます．この置き換えの実装では，内部で
+     * 置き換えが必要なShapeの数だけAction3DがnewされてShapeごとに
+     * 独立したAction3Dがセットされます．これらの複数のAction3Dの
+     * Actionのchangeを一括して行うためにはshapeChange()メソッドを
+     * 使用して下さい．
+     */
+    void replaceShapeWithA3(String shapeFilename,String a3url) throws Exception {
+        a3Data.replaceShapeWithA3(shapeFilename,a3url);
+    }
+
+    /**
+     * ファイル名で指定したShapeがreplaceShapeWithA3()で変更されている
+     * 場合に，そのメソッドの中で生成される全てのAction3Dのアクションを
+     * 一括で変更します．
+     */
+    void shapeChange(String shapeFilename,String actionName) {
+        a3Data.shapeChange(shapeFilename,actionName);
+    }
     void setSound(int actionNo,MediaContainer sound) {
         ;
     }
@@ -619,6 +672,23 @@ class ActionBehavior extends Behavior implements Cloneable {
             setBalloonLoc(actionNo,d,x,y);
         }
     }
+    public void setBalloonLocAll(BalloonDir d,double x,double y) {
+        for (int actionNo=0;actionNo<a3Data.actions.length;actionNo++) {
+            if (d==A3Object.BalloonDir.RIGHT) {
+                a3Data.actions[actionNo].rightBalloonOffset[0] = x;
+                a3Data.actions[actionNo].rightBalloonOffset[1] = y;
+            } else if (d==A3Object.BalloonDir.LEFT) {
+                a3Data.actions[actionNo].leftBalloonOffset[0] = x;
+                a3Data.actions[actionNo].leftBalloonOffset[1] = y;
+            } else if (d==A3Object.BalloonDir.TOP) {
+                a3Data.actions[actionNo].topBalloonOffset[0] = x;
+                a3Data.actions[actionNo].topBalloonOffset[1] = y;
+            } else if (d==A3Object.BalloonDir.BOTTOM) {
+                a3Data.actions[actionNo].bottomBalloonOffset[0] = x;
+                a3Data.actions[actionNo].bottomBalloonOffset[1] = y;
+            }
+        }
+    }
     public void getBalloonLoc(BalloonDir d,double ret[]) {
         getBalloonLoc(actionNo,d,ret);
     }
@@ -652,6 +722,11 @@ class ActionBehavior extends Behavior implements Cloneable {
             setBalloonDir(actionNo,d);
         }
     }
+    public void setBalloonDirAll(BalloonDir d) {
+        for (int i=0;i<a3Data.actions.length;i++) {
+            a3Data.actions[i].balloonDirection = d;
+        }
+    }
     void setSoundLocQuat(Vector3d v,Quat4d q) {
         a3Data.actions[actionNo].setSoundLocQuat(v,q);
     }
