@@ -140,6 +140,11 @@ public class JA3SubCanvas extends JCanvas3D implements A3CanvasInterface, Compon
         subCamBehavior.setA3VirtualUniverse(vu);
     }
 
+    @Override
+    public A3VirtualUniverse getVirtualUniverse() {
+        return virtualUniverse;
+    }
+
     //カメラ制御
     @Override
     public void setDefaultCameraLoc(double x,double y,double z) {
@@ -588,6 +593,11 @@ public class JA3SubCanvas extends JCanvas3D implements A3CanvasInterface, Compon
         return pickingBehavior.pickA3(x,y);
     }
 
+    @Override
+    public A3Object pick(Vector3d origin,Vector3d dir) {
+        return pickingBehavior.pickA3(origin,dir);
+    }
+
     @Override
     public TransformGroup getTransformGroupForViewPlatform() {
         return tg;
