@@ -137,6 +137,44 @@ class SubCameraBehavior extends Behavior {
         cameraNextV.set(loc);
     }
 
+    /**
+     * 現在のカメラ位置に引数のベクトルを加えたものを新しカメラ位置に指定します。
+     * 自動的に補完が働き滑らかにカメラの位置が
+     * 変ります。
+     */
+    public void addCameraLoc(double x,double y,double z) {
+        cameraNextV.x += x;
+        cameraNextV.y += y;
+        cameraNextV.z += z;
+    }
+
+    /**
+     * 現在のカメラ位置に引数のベクトルを加えた物を新しカメラの位置に指定します。
+     * 自動的に補完が働き滑らかにカメラの位置が
+     * 変ります。
+     */
+    public void addCameraLoc(Vector3d loc) {
+        cameraNextV.add(loc);
+    }
+
+    /**
+     * 現在のカメラ位置に引数のベクトルを加えた物を新しカメラの位置に即時に指定します。
+     */
+    public void addCameraLocImmediately(double x,double y,double z) {
+        cameraNextV.x += x;
+        cameraNextV.y += y;
+        cameraNextV.z += z;
+        cameraNowV.set(cameraNextV);
+    }
+
+    /**
+     * 現在のカメラ位置に引数のベクトルを加えた物を新しカメラの位置に即時に指定します。
+     */
+    public void addCameraLocImmediately(Vector3d loc) {
+        cameraNextV.add(loc);
+        cameraNowV.set(cameraNextV);
+    }
+
     /**
      * カメラの現在位置を返します。
      */
@@ -144,6 +182,13 @@ class SubCameraBehavior extends Behavior {
         return new Vector3d(cameraNowV);
     }
 
+    /**
+     * カメラの目標位置を返します。
+     */
+    public Vector3d getCameraTargetLoc() {
+        return new Vector3d(cameraNextV);
+    }
+
     /**
      * カメラの回転を指定します。自動的に補完が働き滑らかにカメラの回転が
      * 変ります。
@@ -176,6 +221,24 @@ class SubCameraBehavior extends Behavior {
         cameraNextQ.set(quat);
     }
 
+    public void mulCameraQuat(double x,double y,double z,double w) {
+        cameraNextQ.mul(new Quat4d(x,y,z,w));
+    }
+
+    public void mulCameraQuat(Quat4d quat) {
+        cameraNextQ.mul(quat);
+    }
+
+    public void mulCameraQuatImmediately(double x,double y,double z,double w) {
+        cameraNextQ.mul(new Quat4d(x,y,z,w));
+        cameraNowQ.set(cameraNextQ);
+    }
+
+    public void mulCameraQuatImmediately(Quat4d quat) {
+        cameraNextQ.mul(quat);
+        cameraNowQ.set(cameraNextQ);
+    }
+
     /**
      * カメラの現在の回転を返します。
      */
@@ -183,6 +246,10 @@ class SubCameraBehavior extends Behavior {
         return new Quat4d(cameraNowQ);
     }
 
+    public Quat4d getCameraTargetQuat() {
+        return new Quat4d(cameraNextQ);
+    }
+
     /**
      * カメラの回転を指定します。自動的に補完が働き滑らかにカメラの回転が
      * 変ります。
@@ -215,6 +282,32 @@ class SubCameraBehavior extends Behavior {
         cameraNextQ.set(cameraNowQ);
     }
 
+    public void mulCameraRot(double x,double y,double z) {
+        cameraNextQ.mul(Util.euler2quat(x,y,z));
+    }
+
+    public void mulCameraRot(Vector3d rot) {
+        cameraNextQ.mul(Util.euler2quat(rot));
+    }
+
+    public void mulCameraRotImmediately(double x,double y,double z) {
+        cameraNextQ.mul(Util.euler2quat(x,y,z));
+        cameraNowQ.set(cameraNextQ);
+    }
+
+    public void mulCameraRotImmediately(Vector3d rot) {
+        cameraNextQ.mul(Util.euler2quat(rot));
+        cameraNowQ.set(cameraNextQ);
+    }
+
+    public Vector3d getCameraRot() {
+        return Util.quat2euler(cameraNowQ);
+    }
+
+    public Vector3d getCameraTargetRot() {
+        return Util.quat2euler(cameraNextQ);
+    }
+
     /**
      * カメラの拡大率を指定します。自動的に補完が働き滑らかにカメラの拡大率が
      * 変ります。拡大率がデフォルトの1.0の時は10cmより手前と100mより奥はクリッピングされて
@@ -236,6 +329,15 @@ class SubCameraBehavior extends Behavior {
         cameraNextS = s;
     }
 
+    public void mulCameraScale(double s) {
+        cameraNextS *= s;
+    }
+
+    public void mulCameraScaleImmediately(double s) {
+        cameraNextS *= s;
+        cameraNowS = cameraNextS;
+    }
+
     /**
      * カメラの拡大率を返します。
      */
@@ -243,6 +345,10 @@ class SubCameraBehavior extends Behavior {
         return cameraNowS;
     }
 
+    public double getCameraTargetScale() {
+        return cameraNextS;
+    }
+
     /**
      * ルックアットポイントと上方向ベクトルを使って、カメラの回転を
      * 指定します。
