@@ -7,8 +7,10 @@ import javax.media.j3d.*;
 class TimerBehavior extends Behavior {
     A3VirtualUniverse universe;
     Material emphasizerMaterial;
+    ArrayList<Runnable> runnableQueue = null;
     TimerBehavior(A3VirtualUniverse u) {
         universe = u;
+        runnableQueue = new ArrayList<Runnable>();
     }
     void setEmphasizerMaterial(Material m) {
         emphasizerMaterial = m;
@@ -30,5 +32,19 @@ class TimerBehavior extends Behavior {
         float g = c.getGreen()/255.0f;
         float b = c.getBlue()/255.0f;
         emphasizerMaterial.setDiffuseColor(r,g,b);
+        //runnableQueueの処理
+        ArrayList<Runnable> runnableCopy = null;
+        synchronized(runnableQueue) {
+            runnableCopy = (ArrayList<Runnable>)runnableQueue.clone();
+            runnableQueue.clear();
+        }
+        for (Runnable rr:runnableCopy) {
+            rr.run();
+        }
+    }
+    void addRunnable(Runnable r) {
+        synchronized(runnableQueue) {
+            runnableQueue.add(r);
+        }
     }
 }
